@@ -4,13 +4,11 @@ use strict;
 use warnings;
 
 use utf8;
-use subs qw();
-use vars qw($VERSION);
 
 use Carp qw(croak);
 use DBI;
 
-$VERSION = '0.010_004';
+our $VERSION = '0.010_005';
 
 =encoding utf8
 
@@ -444,7 +442,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2013-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2013-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the Artistic License 2.0.
 
